==> sammaadmin-1.00.tar.gz: htdocs/user/postldapadmin/samma/samma_mod.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * SaMMAѹ
 *
 * $RCSfile: samma_mod.php,v $
 * $Revision: 1.7 $
 * $Date: 2010/06/29 09:40:02 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");


/********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "Ź沽ѹ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;
        global $del_list;
        global $mod_data;
        global $dispusr;

        /* 桼̾ */
        $user = htmlspecialchars($dispusr);

        /* ɥᥤ̾ */
        $domain = "";
        if (isset($mod_data["domain"]) === TRUE) {
            $domain = htmlspecialchars($mod_data["domain"]);
        }

        $disp_dom = "";
        if (isset($mod_data["disp_dom"]) === TRUE) {
            $disp_dom = htmlspecialchars($mod_data["disp_dom"]);
        }

        /* ѥ */
        $pass_radio_r = "checked";
        $pass_radio_i = "";

        if (isset($mod_data["password"]) === TRUE) {
            if ($mod_data["password"] == 0) {
                $pass_radio_r = "";
                $pass_radio_i = "checked";
            }
        }

        /* ̥ѥ */
        $indivipass = "";
        if (isset($mod_data["indivipass"]) === TRUE) {
            $indivipass = htmlspecialchars($mod_data["indivipass"]);
        }

        /* Ź沽롼 */
        $rule_radio_on = "checked";
        $rule_radio_off = "";

        if (isset($mod_data["rule"]) === TRUE) {
            if ($mod_data["rule"] == 0) {
                $rule_radio_on = "";
                $rule_radio_off = "checked";
            }
        }

        /* ݻ */
        $hidden_del = "";
        if (is_array($del_list) === TRUE) {
            foreach ($del_list as $delval) {
                $hidden_del .=<<<EOD
  <input type="hidden" name="delete[]" value="$delval">
EOD;
            }
        }
  
        print<<<EOD
<form method="POST" action="samma_mod.php" name="rcpt_mod">

  <table class="table">

    <tbody>
      <tr>
        <td class="key1">桼̾</td>
        <td class="mod_value">
          $user
        </td>
      </tr>
      <tr>
        <td class="key1">ɥᥤ̾/᡼륢ɥ쥹</td>
        <td class="value">
          $disp_dom
          <input type="hidden" name="domname" value="$domain">
        </td>
      </tr>
      <tr>
        <td class="key1">Ź沽ѥ</td>
        <td class="value">
          <input type="radio" name="password" value="1" $pass_radio_r>
          <br>
          <input type="radio" name="password" value="0" $pass_radio_i><input type="text" size="16" name="indivipass" value="$indivipass" maxlength="20">
      </tr>
      <tr>
        <td class="key1">Ź沽롼</td>
        <td class="value">
          <input type="radio" name="rule" value="1" $rule_radio_on>о
          <br>
          <input type="radio" name="rule" value="0" $rule_radio_off>о
        </td>
      </tr>
    </tbody>

  </table>
  <div class="must">ɥᥤ̾Ƭˡ@פĤȡ<br>פΤȤӤޤ<br>᡼륢ɥ쥹ϴפΤȤӤޤ</div>
  <br>
  <input type="submit" name="mod" value="" class="mod_btn">
  <input type="submit" name="del" value="" class="del_btn" onClick="return msgConfirm('ޤ\\nǤ')">
  <input type="submit" name="cancel" value="" class="cancel_btn">
  <input type="hidden" name="sk" value="$sesskey">

$hidden_del

</form>

EOD;

    }
};

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata ($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ɽ */
$mod_data = "";
if (isset($_POST["domname"]) === TRUE) {
    $key_domain = $_POST["domname"];
}
if (get_one_data($key_domain, $mod_data) === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "Ź沽μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/* ʬ */
/* ѹ */
if (isset($_POST["mod"]) === TRUE) {
    /* ߤΥ롼 */
    $old_rule = $mod_data["rule"];

    /* ͼ */
    $mod_data["password"] = $_POST["password"];
    $mod_data["rule"] = $_POST["rule"];
    $mod_data["indivipass"] = $_POST["indivipass"];

    /* ϥå */
    if (check_rcptmod_data($mod_data) === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
    } else {
        /* 桼ǤΥХ̵ */
        $env['user_self'] = FALSE;

        /*  */
        $ret = mod_rcpt_data($mod_data, $old_rule);

        /* ƥ२顼 */
        if ($ret === FAIL) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $err_msg = "ι˼Ԥޤ(" . $mod_data["disp_dom"] . ")";
            $sys_err = TRUE;
            $pg->display(NULL);
            exit (1);
        /*  */
        } elseif ($ret !== SUCCESS) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $err_msg = "ι˼Ԥޤ(" . $mod_data["disp_dom"] . ")";
        } else {
            /*  */
            $err_msg = "ιޤ(" . $mod_data["disp_dom"] . ")";
            result_log(OPERATION . ":OK:" . $err_msg);

            /* ̤ */
            dgp_location("index.php", $err_msg);
            exit (0);
        }
    }
/*  */
} elseif (isset($_POST["del"]) === TRUE) {
    /* оݺ */
    $del_dom[] = $mod_data["domain"];

    /* 桼ǤΥХ̵ */
    $env['user_self'] = FALSE;

    /*  */
    $ret = ldap_enc_del($userdn, $del_dom);
    /* оݤʤ顼̾泌顼 */
    if ($ret === LDAP_ERR_NODATA) {
        $err_msg = "" . $err_msg;
        result_log(OPERATION . ":NG:" . $err_msg);
    /* 顼ϥƥ२顼 */
    } elseif ($ret !== LDAP_OK) {
        result_log(OPERATION . ":NG:" . $err_msg);
        /* 桼ѥåѹ */
        $err_msg = "κ˼Ԥޤ(" . $mod_data["domain"] . ")";
        $sys_err = TRUE;
        $pg->display(CONTENT);
        exit (1);
    /*  */
    } else {
        $err_msg = "" . $suc_msg;
        result_log(OPERATION . ":OK:" . $err_msg);

        /* ̤ */
        dgp_location("index.php", $err_msg);
        exit (0);
    }
/* 󥻥 */
} elseif (isset($_POST["cancel"]) === TRUE) {
    /* ̤ */
    page_location("index.php", $del_list);
    exit (0);

}


/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> sammaadmin-2.00.tar.gz: htdocs/user/postldapadmin/samma/samma_mod.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * SaMMAѹ
 *
 * $RCSfile: samma_mod.php,v $
 * $Revision: 1.9 $
 * $Date: 2013/08/22 09:32:35 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");


/********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "Ź沽ѹ");
define("TMPLFILE", "samma/samma_user_mod.tmpl");

/***********************************************************
 * ؿ
 **********************************************************/
/***********************************************************
 * set_tag_data()
 *
 * ֤ξ򥻥åȤ
 *
 * []
 *      $tag  ֤
 *
 * [֤]
 *       ʤ
 **********************************************************/
function set_tag_data(&$tag) {
    global $sesskey;
    global $del_list;
    global $mod_data;
    global $dispusr;

    /* 桼̾ */
    $user = htmlspecialchars($dispusr);
    $tag["<<USER>>"] = $user;

    /* ɥᥤ̾ */
    $domain = "";
    if (isset($mod_data["domain"]) === TRUE) {
        $domain = htmlspecialchars($mod_data["domain"]);
    }
    $tag["<<DOMAIN>>"] = $domain;

    $disp_dom = "";
    if (isset($mod_data["disp_dom"]) === TRUE) {
        $disp_dom = htmlspecialchars($mod_data["disp_dom"]);
    }
    $tag["<<DISP_DOM>>"] = $disp_dom;

    /* ѥ */
    $pass_radio_r = "checked";
    $pass_radio_i = "";

    if (isset($mod_data["password"]) === TRUE) {
        if ($mod_data["password"] == 0) {
            $pass_radio_r = "";
            $pass_radio_i = "checked";
        }
    }
    $tag["<<PASS_RADIO_R>>"] = $pass_radio_r;
    $tag["<<PASS_RADIO_I>>"] = $pass_radio_i;

    /* ̥ѥ */
    $indivipass = "";
    if (isset($mod_data["indivipass"]) === TRUE) {
        $indivipass = htmlspecialchars($mod_data["indivipass"]);
    }
    $tag["<<INDIVIPASS>>"] = $indivipass;

    /* Ź沽롼 */
    $rule_radio_on = "checked";
    $rule_radio_off = "";

    if (isset($mod_data["rule"]) === TRUE) {
        if ($mod_data["rule"] == 0) {
            $rule_radio_on = "";
            $rule_radio_off = "checked";
        }
    }
    $tag["<<RULE_RADIO_ON>>"] = $rule_radio_on;
    $tag["<<RULE_RADIO_OFF>>"] = $rule_radio_off;

    return TRUE;
}

/***********************************************************
 * 
 **********************************************************/
$tag = array();

/* å󥭡ѿ */
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata ($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    $sys_err = TRUE;
    syserr_display();
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ɽ */
$mod_data = "";
if (isset($_POST["domname"]) === TRUE) {
    $key_domain = $_POST["domname"];
}
if (get_one_data($key_domain, $mod_data) === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "Ź沽μ˼Ԥޤ";
    $sys_err = TRUE;
    syserr_display();
    exit (1);
}

/* ʬ */
/* ѹ */
if (isset($_POST["mod"]) === TRUE) {
    /* ߤΥ롼 */
    $old_rule = $mod_data["rule"];

    /* ͼ */
    $mod_data["password"] = $_POST["password"];
    $mod_data["rule"] = $_POST["rule"];
    $mod_data["indivipass"] = $_POST["indivipass"];

    /* ϥå */
    if (check_rcptmod_data($mod_data) === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
    } else {
        /* 桼ǤΥХ̵ */
        $env['user_self'] = FALSE;

        /*  */
        $ret = mod_rcpt_data($mod_data, $old_rule);

        /* ƥ२顼 */
        if ($ret === FAIL) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $err_msg = "ι˼Ԥޤ(" . $mod_data["disp_dom"] . ")";
            $sys_err = TRUE;
            syserr_display();
            exit (1);
        /*  */
        } elseif ($ret !== SUCCESS) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $err_msg = "ι˼Ԥޤ(" . $mod_data["disp_dom"] . ")";
        } else {
            /*  */
            $err_msg = "ιޤ(" . $mod_data["disp_dom"] . ")";
            result_log(OPERATION . ":OK:" . $err_msg);

            /* ̤ */
            dgp_location("index.php", $err_msg);
            exit (0);
        }
    }
/*  */
} elseif (isset($_POST["del"]) === TRUE) {
    /* оݺ */
    $del_dom[] = $mod_data["domain"];

    /* 桼ǤΥХ̵ */
    $env['user_self'] = FALSE;

    /*  */
    $ret = ldap_enc_del($userdn, $del_dom);
    /* оݤʤ顼̾泌顼 */
    if ($ret === LDAP_ERR_NODATA) {
        $err_msg = "" . $err_msg;
        result_log(OPERATION . ":NG:" . $err_msg);
    /* 顼ϥƥ२顼 */
    } elseif ($ret !== LDAP_OK) {
        result_log(OPERATION . ":NG:" . $err_msg);
        /* 桼ѥåѹ */
        $err_msg = "κ˼Ԥޤ(" . $mod_data["domain"] . ")";
        $sys_err = TRUE;
        syserr_display();
        exit (1);
    /*  */
    } else {
        $err_msg = "" . $suc_msg;
        result_log(OPERATION . ":OK:" . $err_msg);

        /* ̤ */
        dgp_location("index.php", $err_msg);
        exit (0);
    }
/* 󥻥 */
} elseif (isset($_POST["cancel"]) === TRUE) {
    /* ̤ */
    dgp_location("index.php", $del_list);
    exit (0);

}


/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

set_tag_data($tag);

/* ڡν */
$ret = display(TMPLFILE, $tag, array(), "", "");
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
